KvFront
==============

KvFront is a GTK+ 3.0 based Redis GUI and Memcached GUI .It is totally free and open source. KvFront features an easy-to -use and straightforward graphical user interface, allowing users to easily work with Redis and Memcached in Linux based GTK+ 3.0 desktop environment.

Its highlights include the ability to manage Redis and Memcached. It supports the most of data structures of Redis and Memcached, as well as to view the status of Redis and Memcached instances. In additon, KvFront also provides the scan alility of Redis , which can scan all keys in Redis.
